@@ -1,6 +1,6 @@
 package MyPageKit::Common;
 
-# $Id: Common.pm,v 1.19 2002/01/08 16:45:12 borisz Exp $
+# $Id: Common.pm,v 1.20 2002/04/03 13:31:14 borisz Exp $
 
 use strict;
 
@@ -154,7 +154,7 @@ Model classes.
 
 T.J. Mather (tjmather@anidea.com)
 
-Boris Zentner (boris@m2b.de)
+Boris Zentner (boris@id9.de)
 
 =head1 COPYRIGHT
 
