@@ -1,6 +1,6 @@
 package Apache::PageKit;
 
-# $Id: PageKit.pm,v 1.175 2002/03/13 22:41:15 borisz Exp $
+# $Id: PageKit.pm,v 1.191 2002/04/30 09:27:39 borisz Exp $
 
 # required for UNIVERSAL->can
 require 5.005;
@@ -34,7 +34,7 @@ use Apache::PageKit::Edit ();
 use Apache::Constants qw(OK DONE REDIRECT DECLINED);
 
 use vars qw($VERSION);
-$VERSION = '1.08';
+$VERSION = '1.09';
 
 %Apache::PageKit::DefaultMediaMap = (
 				     pdf => 'application/pdf',
@@ -45,10 +45,16 @@ $VERSION = '1.08';
 sub startup {
   my ($class, $pkit_root, $server) = @_;
 
-  die 'must specify $server variable in startup.  Usage: Apache::PageKit->startup($pkit_root, $server)' unless $server;
-
   my $s = Apache->server;
 
+  if ( defined $mod_perl::VERSION && $mod_perl::VERSION >= 1.26 ) {
+    $pkit_root = $s->dir_config('PKIT_ROOT')   || die "PKIT_ROOT is not defined! Put PerlSetVar PKIT_ROOT /your/root/path in your httpd.conf";
+    $server    = $s->dir_config('PKIT_SERVER') || die "PKIT_SERVER is not defined! Put PerlSetVar PKIT_SERVER servername in your httpd.conf";
+  } else {
+    $pkit_root || die 'must specify $pkit_root variable in startup.  Usage: Apache::PageKit->startup($pkit_root, $server)';
+    $server    || die 'must specify $server variable in startup.  Usage: Apache::PageKit->startup($pkit_root, $server)';
+  }
+
   # get user and group as specified by User and Group directives
   my $uid = $s->uid;
   my $gid = $s->gid;
@@ -61,6 +67,10 @@ sub startup {
   my $config = Apache::PageKit::Config->new(config_dir => $config_dir,
 					    server => $server);
   $config->parse_xml;
+
+  die "No config data for your server '$server' maybe you mistyped something?"
+    unless exists $Apache::PageKit::Config::server_attr->{$config_dir}->{$server};
+
   my $cache_dir = $config->get_global_attr('cache_dir');
   my $view_cache_dir = $cache_dir ? $cache_dir . '/pkit_cache' :
     $pkit_root . '/View/pkit_cache';
@@ -164,7 +174,7 @@ sub handler ($$){
   };
   if($@){
     if($pk){
-      $pk->fatal_error($@);
+      $status_code = $pk->_fatal_error($@);
     } else {
       if(exists $INC{'Apache/ErrorReport.pm'}){
 	Apache::ErrorReport::fatal($@);
@@ -177,15 +187,27 @@ sub handler ($$){
 }
 
 # called in case die is trapped by eval
-sub fatal_error {
+sub _fatal_error {
   my ($pk, $error) = @_;
-  delete @$pk{qw/session page_session/};
   my $model = $pk->{model};
+  eval {
+    $error = $model->pkit_on_error($error) if $model->can('pkit_on_error');
+  };
+  # just in case we die again inside pkit_on_error
+  $error = $@ if ($@);
+
+  # save changes
+  delete @$pk{qw/session page_session/};
+
+  # the session and page_session references can not be used
+  # inside pkit_cleanup_code -- they are already deleted
   $model->pkit_cleanup_code if $model->can('pkit_cleanup_code');
-  if(exists $INC{'Apache/ErrorReport.pm'}){
+  if( exists $INC{'Apache/ErrorReport.pm'} && $error ){
     Apache::ErrorReport::fatal($error);
   }
-  die $error;
+  die $error if $error;
+
+  return ( defined $pk->{status_code} ? $pk->{status_code} : undef );
 }
 
 # utility function, concats parameters from request parameters into string
@@ -313,7 +335,7 @@ sub prepare_page {
   my $uri_prefix = $config->get_global_attr('uri_prefix') || '';
 
   if($uri_prefix){
-    $uri =~ s(^/$uri_prefix)(/);
+    $uri =~ s(^/$uri_prefix/*)(/); # */
   }
 
   if($model->can('pkit_fixup_uri')){
@@ -328,7 +350,6 @@ sub prepare_page {
   } else {
     $host = $apr->headers_in->{'Host'};
 
-    $uri_prefix =~ s!/$!!g;
     $uri_with_query = ((defined( $ENV{HTTPS} ) && $ENV{HTTPS} eq 'on') ? 'https' : 'http') . '://' . $host . ($uri_prefix ? '/' . $uri_prefix : '' ) . $uri;
   }
 #  my $pkit_selfurl;
@@ -369,6 +390,9 @@ sub prepare_page {
     $pk->{page_id} = $model->pkit_get_default_page;
   }
 
+  # store name and page_id for a static file, that require a login
+  my %static_file;
+
   # redirect "not found" pages
   unless ($pk->page_exists($pk->{page_id})){
     # first try to see if we can find a static file that we
@@ -383,34 +407,22 @@ sub prepare_page {
         last if ($filename);
       }
 
-      $pk->{page_id} = ($config->uri_match($pk->{page_id})
-	|| $config->get_global_attr('not_found_page'))
-	  || $model->pkit_get_default_page;
+      $pk->{page_id} = $config->uri_match($pk->{page_id})
+	|| $config->get_global_attr('not_found_page')
+	|| $model->pkit_get_default_page;
       unless ($pk->page_exists($pk->{page_id})){
-	# if not_found_page is static, the return DECLINED...
+	# if not_found_page is static, then return DECLINED...
 	$filename = $pk->static_page_exists($pk->{page_id});
       }
     }}
     if ($filename){
-      require MIME::Types;
-      my ($media_type, $content_encoding) = MIME::Types::by_suffix($filename);
-      if (defined $media_type) {
-        $apr->content_type($media_type);
-        if($media_type eq "text/html" && $pk->{use_gzip}){
-          my $gzipped = $view->get_static_gzip($filename);
-          if ($gzipped){
-            $apr->content_encoding("gzip");
-            $apr->send_http_header;
-            $apr->print($gzipped) unless $apr->header_only;
-            return DONE;
-          }
-        }
+      my $require_login  = $config->get_page_attr($pk->{page_id},'require_login') || 'no';
+      my $protect_static = $config->get_global_attr('protect_static') || 'yes';
+      if ( $require_login eq 'no' || $protect_static ne 'yes' ) {
+        return $pk->_send_static_file($filename);
       }
-
-      # set path_info to '', otherwise Apache tacks it on at the end
-      $apr->path_info('');
-      $apr->filename($filename);
-      return DECLINED;
+      $static_file{name}    = $filename;
+      $static_file{page_id} = $pk->{page_id};
     }
   }
 
@@ -431,7 +443,7 @@ sub prepare_page {
 
   if( $lang = $apr->param('pkit_lang') ){
     $session->{'pkit_lang'} = $lang if $session;
-  } elsif ( $session && ! exists $pk->{is_new_session} ){
+  } elsif ( $session && !exists $pk->{is_new_session} ){
     $lang = $session->{'pkit_lang'} if exists $session->{'pkit_lang'};
   }
 
@@ -522,6 +534,15 @@ sub prepare_page {
 
   $model->pkit_common_code if $model->can('pkit_common_code');
 
+  if ( $static_file{name} ) {
+    if ( $pk->{page_id} eq $static_file{page_id} ) {
+      # page_id is the same as we tested already (this may save some stat calls)
+      return $pk->_send_static_file($static_file{name});
+    } elsif ( my $filename = $pk->static_page_exists($pk->{page_id}) ) {
+      return $pk->_send_static_file($filename);
+    }
+  }
+
   # run the page code!
   $pk->page_code;
   # check for the statuscode that can be set with $model->pkit_status_code
@@ -547,6 +568,29 @@ sub prepare_page {
   return OK;
 }
 
+sub _send_static_file {
+  my ( $pk, $filename )  = @_;
+  my $apr = $pk->{apr};
+  require MIME::Types;
+  my ($media_type) = MIME::Types::by_suffix($filename);
+      if (defined $media_type) {
+        $apr->content_type($media_type);
+        if($media_type eq "text/html" && $pk->{use_gzip} ne 'none') {
+          my $gzipped = $pk->{view}->get_static_gzip($filename); 
+          if ($gzipped){
+            $apr->content_encoding("gzip");
+            $apr->send_http_header;
+            $apr->print($gzipped) unless $apr->header_only;
+            return DONE;
+          }
+        }
+      }
+      # set path_info to '', otherwise Apache tacks it on at the end
+      $apr->path_info('');
+      $apr->filename($filename);
+      return DECLINED;
+}
+
 sub _check_gzip {
   my $pk = shift;
   # check Accent-Encoding or if the user_agent field for Unix/Mac Netscape
@@ -607,6 +651,7 @@ sub prepare_and_print_view {
     shift @fillinform_objects_array;
   }
   $view->{fillinform_objects} = [ grep {$_->param} @fillinform_objects_array ];
+  $view->{ignore_fillinform_fields} = $pk->{ignore_fillinform_fields};
 
   my $page_rpit = $config->get_page_attr($page_id,'request_param_in_tmpl') || '';
   my $global_rpit = $config->get_global_attr('request_param_in_tmpl') || 'no';
@@ -631,7 +676,6 @@ sub prepare_and_print_view {
   my $browser_cache =  $config->get_page_attr($page_id,'browser_cache') || 'yes';
   $apr->header_out('Expires','-1') if $apr->param('pkit_logout') || $browser_cache eq 'no' || $apr->connection->user;
 
-  my $retcharset;
   my $default_output_charset = $view->{default_output_charset};
   my @charsets = ();
   if($output_media eq 'text/html'){
@@ -666,9 +710,13 @@ sub prepare_and_print_view {
     my $fop_command = $config->get_server_attr('fop_command') ||
       $config->get_global_attr('fop_command');
     die "fop_command not specifed in configuration - must specify to use Apache XML FOP to generate PDFs" unless $fop_command;
-    my $error_message = `$fop_command $fo_file $pdf_file 2>&1 1>/dev/null`;
+ #   my $error_message = `$fop_command $fo_file $pdf_file 2>&1 1>/dev/null`;
+    my $error_message = `$fop_command $fo_file $pdf_file 2>&1`;
 
-    if(-s "$pdf_file"){
+    ## the recommended fop converter has no usefull error messages.
+    ## the errormoessages go also to STDOUT
+    ## and the returncode is always 0
+    unless ($error_message =~ /^\[ERROR\]:/m){
       local $/;
       open PDF_OUTPUT, "<$pdf_file" or die "can't open file: $pdf_file ($!)";
       $$output_ref = <PDF_OUTPUT>;
@@ -682,10 +730,6 @@ sub prepare_and_print_view {
     $apr->content_type($output_media);
   }
 
-  if($pk->{use_gzip} eq 'all'){
-    $apr->content_encoding("gzip");
-  }
-
   # for a head request
   if ($apr->header_only) {
     $apr->send_http_header if $apr->is_initial_req;
@@ -696,7 +740,7 @@ sub prepare_and_print_view {
   $model->pkit_output_filter($output_ref)
     if $model->can('pkit_output_filter');
 
-  my $converted_data;
+  my ( $converted_data, $retcharset );
   if ($output_media eq 'text/html'){
     my $data;
     while (@charsets){
@@ -710,26 +754,26 @@ sub prepare_and_print_view {
       $retcharset = undef;
     }
 
+    ## here no action is needed, if we did not convert the data to anything usefull.
+    ## we deliver in our default_output_charset.
+
     # correct the header
-    $apr->content_encoding('') unless ($retcharset);
     $apr->content_type("text/html; charset=$retcharset") if ($retcharset);
     $apr->content_type("text/html")                      unless ($retcharset);
   }
 
+  # only pages with propper $retcharset are tranfered gzipped.
+  # this can maybe changed!? Needs some tests
+  my $send_gzipped = ( $retcharset && $pk->{use_gzip} eq 'all' );
+  $apr->content_encoding('gzip') if ($send_gzipped);
+
   $apr->send_http_header if $apr->is_initial_req;
 
-  if($converted_data){
-    if($pk->{use_gzip} eq 'all'){
-      $apr->print(Compress::Zlib::memGzip($converted_data));
-    } else {
-      $apr->print($converted_data);
-    }
+
+  if ($send_gzipped) {
+    $apr->print(Compress::Zlib::memGzip($converted_data || $$output_ref));
   } else {
-    if($pk->{use_gzip} eq 'all' && $retcharset){
-      $apr->print(Compress::Zlib::memGzip($$output_ref));
-    } else {
-      $apr->print($$output_ref);
-    }
+    $apr->print($converted_data || $$output_ref);
   }
 }
 
@@ -1308,8 +1352,23 @@ The following method is available to the user as Apache::PageKit API.
 
 This function should be called at server startup from your httpd.conf file:
 
+If you use PageKit >= 1.09 and mod_perl < 1.26, the follow the instructions
+for PageKit < 1.09.
+
+  PerlSetVar PKIT_ROOT /path/to/pagekit/files
+  PerlSetVar PKIT_SERVER staging
+  PerlHandler +Apache::PageKit
   <Perl>
-        Apache::PageKit->startup("/path/to/pagekit/files","staging");
+    Apache::PageKit->startup;
+  </Perl>
+
+PageKit < 1.09 should be started this way:
+
+  PerlSetVar PKIT_ROOT /path/to/pagekit/files
+  PerlSetVar PKIT_SERVER staging
+  PerlHandler +Apache::PageKit
+  <Perl>
+    Apache::PageKit->startup("/path/to/pagekit/files","staging");
   </Perl>
 
 Where the first argument is the root directory of the
@@ -1332,7 +1391,7 @@ L<Data::FormValidator>
 
 =head1 VERSION
 
-This document describes Apache::PageKit module version 1.08
+This document describes Apache::PageKit module version 1.09
 
 =head1 NOTES
 
@@ -1385,15 +1444,18 @@ Fixes, Bug Reports, Docs have been generously provided by:
   Anton Berezin
   Chris Hamilton
   David Christian
-  Daniel Gardner
   Rob Starkey
   Anton Permyakov
+  John Robinson
+  Daniel Gardner
   Andy Massey
   Michael Cook
   Michael Pheasant
   John Moose
   Sheldon Hearn
   Vladimir Sekissov
+  Gabriel Burka
+  Tomasz Konefal
 
 Also, thanks to Dan Von Kohorn for helping shape the initial architecture
 and for the invaluable support and advice. 
