@@ -1,6 +1,6 @@
 package Apache::PageKit::Model;
 
-# $Id: Model.pm,v 1.74 2002/03/14 14:41:38 borisz Exp $
+# $Id: Model.pm,v 1.77 2002/04/30 09:27:39 borisz Exp $
 
 use integer;
 use strict;
@@ -20,6 +20,8 @@ sub new {
   }
   $self->{pkit_pk}->{output_param_object} ||= Apache::PageKit::Param->new();
   $self->{pkit_pk}->{fillinform_object} ||= Apache::PageKit::Param->new();
+  $self->{pkit_pk}->{ignore_fillinform_fields} ||= [];
+
   return $self;
 }
 
@@ -196,7 +198,7 @@ sub pkit_message {
     if ($@) {
       die "Charset $input_charset or $default_output_charset not supported by Text::Iconv";
     }
-    $message = $converter->convert($message);
+    $message = $converter->convert($message) || die "Can not convert page from $input_charset to $default_output_charset";;
   }
 
   my $array_ref = $model->output('pkit_messages') || [];
@@ -249,6 +251,13 @@ sub fillinform {
   return shift->{pkit_pk}->{fillinform_object}->param(@_);
 }
 
+# undocumented
+sub ignore_fillinform_fields {
+  my $model = shift;
+  push @{$model->{pkit_pk}->{ignore_fillinform_fields}}, @_;
+}
+
+
 sub output {
   return shift->{pkit_pk}->{output_param_object}->param(@_);
 }
@@ -442,7 +451,7 @@ sub _change_params {
       } elsif ( $type eq 'ARRAY' ) {
         _change_array( $converter, $_ );
       } else {
-        $_ = $converter->convert($_);
+        $_ = $converter->convert($_) || die "Can not convert from default_input_charset to default_output_charset";
       }
     }
   }
@@ -456,7 +465,7 @@ sub _change_params {
       } elsif ( $type eq 'ARRAY' ) {
         _change_array( $converter, $_ );
       } else {
-        $_ = $converter->convert($_);
+        $_ = $converter->convert($_) || die "Can not convert from default_input_charset to default_output_charset";
       }
     }
   }
@@ -468,7 +477,7 @@ sub _change_params {
     } elsif ( $type eq 'ARRAY' ) {
       _change_array( $converter, $_[$i] );
     } else {
-      $_[$i] = $converter->convert($_[$i]);
+      $_[$i] = $converter->convert($_[$i]) || die "Can not convert from default_input_charset to default_output_charset";
     }
   }
 }
@@ -520,7 +529,7 @@ Method in derived class.
 
 T.J. Mather (tjmather@anidea.com)
 
-Boris Zentner (boris@m2b.de)
+Boris Zentner (borisz@users.sourceforge.net)
 
 =head1 COPYRIGHT
 
